client library
Classes
- Client
- Client sends and receives data between any NKN clients regardless their network condition without setting up a server or relying on any third party services. Data are end to end encrypted by default.
- ClientConfig
- Client config
- ConnState
- Connection state of a sub-client (match nkn-sdk-go ConnState).
- CrossSendPolicy
- CrossSendPolicy constants for MultiClient (match nkn-sdk-go).
- DnsResolverConfig
- DnsResolver Config
- EthResolverConfig
- EthResolver Config
- MessageEventType
- Message event type constants
- MessageType
- NKN message's PayloadType
- OnConnect
- Event emitting channel when client connects to node and becomes ready to send messages.
- OnMessage
- Event emitting channel when client receives a message (not including reply or ACK).
- OnMessageEvent
- Event emitting channel for message send/receive events for monitoring and reporting.
- SubClientConnectionState
- Connection state for one sub-client.