CrossSendPolicy class

CrossSendPolicy constants for MultiClient (match nkn-sdk-go).

Constructors

CrossSendPolicy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

allConnected → const int
All connected lines (redundant sending)
anyConnected → const int
Any connected line sends (cross)
none → const int
No cross send
preferStable → const int
Select the most stable/low latency line