OnMessageEvent class

Event emitting channel for message send/receive events for monitoring and reporting.

Constructors

OnMessageEvent({int? type, String? clientAddr, int? subClientID, List<String>? destinations, String? src, Uint8List? messageId, int? messageType, bool? encrypted, int? dataSize, bool? noReply, String? error, int? timestamp})

Properties

clientAddr String?
Client address that sent/received the message
getter/setter pair
dataSize int?
Data size in bytes
getter/setter pair
destinations List<String>?
Destination addresses (for send events)
getter/setter pair
encrypted bool?
Whether message is encrypted
getter/setter pair
error String?
Error if operation failed (for send events)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageId Uint8List?
Message ID
getter/setter pair
messageType int?
Message type (BinaryType, TextType, etc.)
getter/setter pair
noReply bool?
Whether message has NoReply flag
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
Source address (for receive events)
getter/setter pair
subClientID int?
Sub-client ID (nil for Client, set for MultiClient)
getter/setter pair
timestamp int?
Event timestamp in milliseconds
getter/setter pair
type int?
Event type (MessageEventType)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited