SubClientConnectionState class

Connection state for one sub-client.

Constructors

SubClientConnectionState({required int index, required int state, int reconnectCount = 0, int sendFailureCount = 0, int connectTimeMs = 0})

Properties

connectionDurationSeconds int
Connection duration in seconds (0 if not connected or unknown).
no setter
connectTimeMs int
Connection start time in milliseconds since epoch (0 if not available).
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
reconnectCount int
Reconnect count (from ClientStats).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendFailureCount int
Send failure count (from ClientStats).
final
stabilityScore double
Stability score 0..1 (same formula as nkn-sdk-go CalculateClientScore, without duration if connectTimeMs missing).
no setter
state int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited